.. image:: https://img.shields.io/pypi/v/unixsig.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/unixsig/
.. image:: https://github.com/Clivern/unixsig/actions/workflows/ci.yml/badge.svg
    :alt: Build Status
    :target: https://github.com/Clivern/unixsig/actions/workflows/ci.yml

|

========
unixsig
========

    Python Package to Handle Unix Signals.


Note
====

This project is created and maintained for Cattle. see https://github.com/Clivern/Cattle
